yakumo.neutron.v2.lbaas.member

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module member |
[hide private]
[frames] | no frames]

# Module member

source code

Resource class and its manager for LBaaS backend members in Networking V2 API

Classes | [hide private]
| Resource Resource class for LBaaS backend members in Networking V2 API
| Manager Manager class for LBaaS backend members in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lbaas``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('address', 'address', mapper.Noop), ('pro
      tocol_port', 'protocol_port', mapper.Noop), ('weight', 'weight', mappe
      r.Noop), ('subnet', 'subnet_id', mapper.Resource('neutron.subnet')), (
      'project', 'tenant_id', mapper.Resource('project')), ('is_enabled', 'a
      dmin_state_up', mapper.Noop),]